This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.tekton.dev group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
operator.tekton.dev/v1alpha1
TektonChainTektonConfigTektonHubTektonInstallerSetTektonPipelineTektonTrigger